@@ -1,9 +1,9 @@
 package Text::Hspell;
-$Text::Hspell::VERSION = '0.0.1';
+$Text::Hspell::VERSION = '0.0.2';
 use strict;
 use warnings;
 
-my $code = <<'EOF';
+use Inline Python => <<'EOF';
 import HspellPy
 
 class HspellPyWrapper:
@@ -13,8 +13,6 @@ class HspellPyWrapper:
     def check_word(self, word):
         return self._hspell.check_word(word);
 EOF
-require Inline;
-Inline->import( Python => $code, );
 
 sub new
 {
@@ -31,7 +29,7 @@ __END__
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 SYNOPSIS
 
@@ -42,6 +40,12 @@ version 0.0.1
 
     print $speller->check_word("שלום") ? "spelled right\n" : "misspelling\n";
 
+=head1 DESCRIPTION
+
+This module allows one to use libhspell ( L<http://hspell.ivrix.org.il/> ) to
+spell check Hebrew words. It requires L<Inline::Python> and HspellPy (
+L<https://pypi.org/project/HspellPy/> ) from PyPI.
+
 =head1 NAME
 
 Text::Hspell - wrapper for the hspell (= Hebrew speller) library
@@ -182,9 +186,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/perl-Text-Hspell>
+L<https://github.com/shlomif/Text-Hspell>
 
-  git clone https://github.com/shlomif/perl-Text-Hspell.git
+  git clone git://github.com/shlomif/Text-Hspell.git
 
 =head1 AUTHOR
 
@@ -193,7 +197,7 @@ Shlomi Fish <shlomif@cpan.org>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/text-hspell/issues>
+L<https://github.com/shlomif/Text-Hspell/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
